define(
//begin v1.x content
({
	insertTableTitle: "Inserisci tabella",
	modifyTableTitle: "Modifica tabella",
	rows: "Righe:",
	columns: "Colonne:",
	align: "Allinea:",
	cellPadding: "Padding celle:",
	cellSpacing: "Spaziatura celle:",
	tableWidth: "Larghezza tabelle:",
	backgroundColor: "Colore di sfondo:",
	borderColor: "Colore bordi:",
	borderThickness: "Spessore bordi",
	percent: "percentuale",
	pixels: "pixel",
	"default": "predefinito",
	left: "sinistra",
	center: "centro",
	right: "destra",
	buttonSet: "Imposta", // translated elsewhere?
	buttonInsert: "Inserisci",
	buttonCancel: "Annulla",

	selectTableLabel: "Seleziona tabella",
	insertTableRowBeforeLabel: "Aggiungi riga prima",
	insertTableRowAfterLabel: "Aggiungi riga dopo",
	insertTableColumnBeforeLabel: "Aggiungi colonna prima",
	insertTableColumnAfterLabel: "Aggiungi colonna dopo",
	deleteTableRowLabel: "Elimina riga",
	deleteTableColumnLabel: "Elimina colonna"
})
	

//end v1.x content
);
